@@ -38,6 +38,6 @@ main (int argc, char *argv[])
   g_vfs_proxy_volume_monitor_daemon_init ();
   return g_vfs_proxy_volume_monitor_daemon_main (argc,
                                                  argv,
-                                                 "org.gtk.Private.HalVolumeMonitor",
+                                                 "org.gtk.vfs.HalVolumeMonitor",
                                                  G_TYPE_HAL_VOLUME_MONITOR);
 }
